/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* NetworkManager system settings service
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2009 Red Hat, Inc.
 */

#ifndef NM_SETTINGS_SERVICE_H
#define NM_SETTINGS_SERVICE_H

#include <dbus/dbus-glib.h>
#include <dbus/dbus-glib-lowlevel.h>
#include <nm-exported-connection.h>
#include <nm-settings-interface.h>

G_BEGIN_DECLS

/**
 * NMSettingsServiceCapabilities:
 * @NM_SETTINGS_SERVICE_CAPABILITY_NONE: the service supports no special
 * capabilities
 * @NM_SETTINGS_SERVICE_CAPABILITY_VPN_HINTS: the service supports sending hints
 * given by the NMSettingsConnectionClass::get_secrets() class method to VPN
 * plugin authentication dialogs.
 * @NM_SETTINGS_SERVICE_CAPABILITY_LAST: bounds checking value; should not be used.
 *
 * #NMSettingsServiceCapabilities indicate various capabilities of the settings
 * service.
 */
typedef enum /*< flags >*/ {
	NM_SETTINGS_SERVICE_CAPABILITY_NONE = 0x0,
	NM_SETTINGS_SERVICE_CAPABILITY_VPN_HINTS = 0x1,

	/* boundary value */
	NM_SETTINGS_SERVICE_CAPABILITY_LAST = NM_SETTINGS_SERVICE_CAPABILITY_VPN_HINTS
} NMSettingsServiceCapabilities;

#define NM_TYPE_SETTINGS_SERVICE            (nm_settings_service_get_type ())
#define NM_SETTINGS_SERVICE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NM_TYPE_SETTINGS_SERVICE, NMSettingsService))
#define NM_SETTINGS_SERVICE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NM_TYPE_SETTINGS_SERVICE, NMSettingsServiceClass))
#define NM_IS_SETTINGS_SERVICE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NM_TYPE_SETTINGS_SERVICE))
#define NM_IS_SETTINGS_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), NM_TYPE_SETTINGS_SERVICE))
#define NM_SETTINGS_SERVICE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NM_TYPE_SETTINGS_SERVICE, NMSettingsServiceClass))

#define NM_SETTINGS_SERVICE_BUS "bus"
#define NM_SETTINGS_SERVICE_SCOPE "scope"
#define NM_SETTINGS_SERVICE_CAPABILITIES "capabilities"

typedef struct {
	GObject parent;
} NMSettingsService;

typedef struct {
	GObjectClass parent;

	/* Returned list must contain all NMExportedConnection objects exported
	 * by the settings service.  The list (but not the NMExportedConnection
	 * objects) will be freed by caller.
	 */
	GSList * (*list_connections) (NMSettingsService *self);

	void (*add_connection) (NMSettingsService *self,
	                        NMConnection *connection,
	                        DBusGMethodInvocation *context, /* Only present for D-Bus calls */
	                        NMSettingsAddConnectionFunc callback,
	                        gpointer user_data);

	void (*add_connection_return) (NMSettingsService *self,
	                               NMConnection *connection,
	                               DBusGMethodInvocation *context, /* Only present for D-Bus calls */
	                               NMSettingsAddConnectionReturnFunc callback,
	                               gpointer user_data);

	/* Padding for future expansion */
	void (*_reserved1) (void);
	void (*_reserved2) (void);
	void (*_reserved3) (void);
	void (*_reserved4) (void);
	void (*_reserved5) (void);
} NMSettingsServiceClass;

GType nm_settings_service_get_type (void);

#define NM_TYPE_SETTINGS_SERVICE_CAPABILITIES (nm_settings_service_capabilities_get_type ())
GType nm_settings_service_capabilities_get_type (void);

NMExportedConnection *nm_settings_service_get_connection_by_path (NMSettingsService *self,
                                                                  const char *path);

void nm_settings_service_export (NMSettingsService *self);

void nm_settings_service_export_with_capabilities (NMSettingsService *self,
                                                   NMSettingsServiceCapabilities capabilities);

void nm_settings_service_export_connection (NMSettingsService *self,
                                            NMSettingsConnectionInterface *exported);

G_END_DECLS

#endif /* NM_SETTINGS_SERVICE_H */
